wall_thickness = 2.0;

size_x = 180.0;
size_y = 180.0;
height = 100.0;

top_x = size_x / 2;
top_y = size_y / 2;

angle = 80;


difference() {
    all(0.0, 0.0);
    all(wall_thickness * sin(angle), wall_thickness);
    signature();
}


module all(offset_xy, offset_z) {
    union() {
        full(offset_xy, offset_z);
        bridge(offset_xy, offset_z);
    }
}

module bridge(offset_xy, offset_z) {
    bridge_height = height * 0.2 - offset_z;
    bridge_offset = bridge_height / tan(angle);

    top_x_b = top_x - offset_xy;
    top_y_b = top_y - offset_xy;

    bridge_x = top_x_b - bridge_offset;
    bridge_y = top_x_b - bridge_offset;
    bridge_z = height - bridge_height;

    polyhedron(
        points = [
            // Base
            [ bridge_x,  bridge_y, bridge_z], // 0
            [ bridge_x, -bridge_y, bridge_z], // 1
            [-bridge_x, -bridge_y, bridge_z], // 2
            [-bridge_x,  bridge_y, bridge_z], // 3

            // Top
            [ top_x_b,  top_y_b, height], // 4
            [ top_x_b, -top_y_b, height], // 5
            [-top_x_b, -top_y_b, height], // 6
            [-top_x_b,  top_y_b, height], // 7
        ],
        faces = [
            [0, 3, 2, 1], // bottom
            [4, 5, 6, 7], // top
            [0, 1, 5, 4], // back
            [2, 3, 7, 6], // front
            [0, 4, 7, 3], // left
            [1, 2, 6, 5], // right
        ]
    );
}

module full(offset_xy, offset_z) {
    union() {
        half(offset_xy, offset_z);

        mirror([1, 0, 0])
        half(offset_xy, offset_z);
    }
}

module half(offset_xy, offset_z) {
    base_o = (height - offset_z) / tan(angle);

    base_x_a = base_o + offset_xy;
    base_x_b = top_x - base_o - offset_xy;
    base_y   = top_y - base_o - offset_xy;

    top_x_a = offset_xy;
    top_x_b = top_x - offset_xy;
    top_y_h = top_y - offset_xy;

    polyhedron(
        points = [
            // Base
            [base_x_a,  base_y, offset_z], // 0
            [base_x_b,  base_y, offset_z], // 1
            [base_x_b, -base_y, offset_z], // 2
            [base_x_a, -base_y, offset_z], // 3

            // Top
            [top_x_a,  top_y_h, height], // 4
            [top_x_b,  top_y_h, height], // 5
            [top_x_b, -top_y_h, height], // 6
            [top_x_a, -top_y_h, height], // 7
        ],
        faces = [
            [0, 3, 2, 1], // bottom
            [4, 5, 6, 7], // top
            [0, 1, 5, 4], // back
            [2, 3, 7, 6], // front
            [0, 4, 7, 3], // left
            [1, 2, 6, 5], // right
        ]
    );
}

module signature() {
    lines = [
        "Peanut Bowl",
        "Designed by Hanno Braun",
    ];

    size   = 4;
    margin = size / 2;

    base_offset = height / tan(angle);

    offset_x = base_offset;
    offset_y = top_y - base_offset;

    linear_extrude(1)
    translate([offset_x + margin, offset_y - margin, 0])
    rotate([0, 0, 90])
    mirror([1, 0, 0])
    union() {
        for (i = [0 : len(lines) - 1]) {
            translate([0, -i * size * 1.5, 0])
            text(
                lines[i],
                size = size,
                font = "osifont",
                halign = "left",
                valign = "top"
            );
        }
    }
}
